/**
 * Object PHP_Serializer
 * 	JavaScript to PHP serialize / unserialize class.
 * This class is designed to convert php variables to javascript
 * and javascript variables to php with a php serialize unserialize
 * compatible way.
 *
 * PARSABLE PHP TO JAVASCRIPT VARIABLES:
 * 	[ PHP TYPE ]			[ JAVASCRIPT TYPE ]
 * 	array				Array
 * 	class				Object (*)
 * 	string				String
 * 	boolean				Boolean
 * 	undefined or null		null
 * 	integer / double 		Number
 *
 * PARSABLE JAVASCRIPT TO PHP VARIABLES:
 *	[ JAVASCRIPT TYPE ]		[ PHP TYPE ]
 *	Array				array
 *	Object				class (*)
 *	String				string
 *	Boolean				boolean
 *	null				null
 *	Number				int or double
 *	Date				class
 *	Error				class
 *	Function			anything (*)
 *	__class				anything (*)
 *
 * (*) NOTE:
 * Any PHP serialized class requires the native PHP class to be used, then it's not a
 * PHP => JavaScript converter, it's just a usefull serializer class for each
 * compatible JS and PHP variable types.
 * However is possible to change public parameters.
 * Lambda, Resources or other dedicated PHP variables are not usefull for JavaScript.
 * (i.e.
 * 	$v = create_function('', 'return 1;'); serialize($v);
 *	$conn = mydb_connect(); serialize($conn);
 * )
 * There are same restrictions for javascript functions too then these will not be sent
 * (but will be filtered / ignored automatically).
 *
 * NEW ON V 1.6a and greater:
 * You can use experimental version of utf8 compatible serialized / unserialized strings
 * with true while you declare your php_serializer var:
 * var php = new PHP_Serializer(true); // enable experimental multybyte convertion
 * _____________________________________________
 *
 * EXAMPLE:
 *	var php = new PHP_Serializer();
 *	alert(php.unserialize(php.serialize(somevar)));
 *	// should alert the original value of somevar
 * ---------------------------------------------
 * @author              Andrea Giammarchi
 * @site		www.devpro.it
 * @date                2005/11/26
 * @lastmod             2006/01/13 07:00 [updated experimental UTF-8 compatible header and utf8_encode php function]
 * @credits		Special thanks to Fabio Sutto for some ideas and some debug
 *			Special thanks to kentaromiura for a faster loop idea while unserialize
 * @version             1.6b, tested on FireFox 1.5, IE 6 SP2 and Opera 8
 */
function PHP_Serializer() {
	this.__cut = (String(Object).indexOf('(')!=16)?9:10;
	if(arguments.length == 1 && arguments[0] == true) {
		this.__m = Math;
		PHP_Serializer.prototype.encode = PHP_Serializer__Encoded_length;
		PHP_Serializer.prototype[String] =
		PHP_Serializer.prototype.__string = PHP_Serializer__String__2;
		PHP_Serializer.prototype.s = PHP_UnSerializer__String_2;
	}
	else {
		PHP_Serializer.prototype[String] =
		PHP_Serializer.prototype.__string = PHP_Serializer__String__1;
		PHP_Serializer.prototype.s = PHP_UnSerializer__String_1;
	}
}
function PHP_Serializer__String__1(__s) {
	return ('s:'+__s.length+':"'+__s+'";');
}
function PHP_UnSerializer__String_1() {
	this.__c += 2;
	var sls = this.__s.substr(this.__c,(this.__s.indexOf(':',this.__c)-this.__c));
	var sli = parseInt(sls);
	sls = this.__c + sls.length + 2;
	this.__c = sls + sli + 2;
	return this.__s.substr(sls,sli);
}
function PHP_Serializer__Encoded_length(__s) {
	__s = __s.replace(/\r\n/g, '\n');
	var a = b = c = 0;
	var len = __s.length;
	while(a < len) {
		c = __s.charCodeAt(a++);
		b += (c<128)?1:((c<2048)?2:((c<65536)?3:4));
	}
	return b;
}
function PHP_Serializer__String__2(__s) {
	return ('s:'+this.encode(__s)+':"'+__s+'";');
}
function PHP_UnSerializer__String_2() {
	this.__c += 2;
	var sls = this.__s.substr(this.__c,(this.__s.indexOf(':',this.__c)-this.__c));
	var sli = parseInt(sls);
	sls = this.__c + sls.length + 2;
	if(sli > 0) {
		var a = sli > 4 ? this.__m.floor(sli/4) : 1;
		while(a > 0) {
			if(this.encode(this.__s.substr(sls,a++)) === sli) {
				sli = a - 1;
				a = 0;
			}
		}
	}
	this.__c = sls + sli + 2;
	return this.__s.substr(sls,sli);
}
function PHP_Serializer__Boolean(__s) {
	return ('b:'+(__s==false?'0':'1')+';');
}
function PHP_UnSerializer__Boolean() {
	var tmp = (this.__s.substr((this.__c+2),1)=='1'?true:false);
	this.__c += 4;
	return tmp;
}
function PHP_Serializer__Number(__s) {
	__s = String(__s);
	return ((__s.indexOf('.')==-1)?'i:'+__s+';':'d:'+__s+';');
}
function PHP_UnSerializer__Number() {
	var sli = this.__s.indexOf(';',(this.__c+1))-2;
	var tmp = Number(this.__s.substr((this.__c+2),(sli-this.__c)));
	this.__c = sli + 3;
	return tmp;
}
function PHP_Serializer__Function() {
	return '';
}
function PHP_Serializer__Undefined() {
	return 'N;';
}
function PHP_UnSerializer__Undefined() {
	this.__c += 2;
	return null;
}
function PHP_Serializer__Common_ArrayObject(__s) {
	var n;
	var a = 0;
	var ser = new Array();
	for(var b in __s) {
		n = (__s[b] == null);
		if(n || (__s[b].constructor != Function && b != '__class')) {
			ser[a++]=((!isNaN(b))?this.__number(b):this.__string(b))+
			(n?this.__undefined():this[__s[b].constructor](__s[b]));
		}
	}
	return [a,ser.join('')];
}
function PHP_UnSerializer__Common_ArrayObject(tmp) {
	this.__c += 2;
	var a = this.__s.indexOf(':',this.__c);
	var k = parseInt(this.__s.substr(this.__c,(a-this.__c))) + 1;
	this.__c = a + 2;
	while(--k)
		tmp[this[this.__s.substr(this.__c,1)]()] = this[this.__s.substr(this.__c,1)]();
	return tmp;
}
function PHP_Serializer__Object(__s) {
	var o = String(__s.constructor);
	var oname = o.substr(this.__cut,o.indexOf('(')-this.__cut);
	var ser = this.__common_array_object(__s);
	return ('O:'+oname.length+':"'+oname+'":'+ser[0]+':{'+ser[1]+'}');
}
function PHP_UnSerializer__Object() {
	var tmp = 's'+this.__s.substr(++this.__c,(this.__s.indexOf(':',(this.__c+3))-this.__c))+';';
	var a = tmp.substr(2,(tmp.indexOf(':',2)-2));
	var o = tmp.substr((a.length+4),parseInt(a));
	if(eval("typeof("+o+") == 'undefined'"))
		eval('function '+o+'(){}');
	this.__c += (tmp.length-3);
	eval('tmp = this.__common(new '+o+'());');
	++this.__c;
	return tmp;
}
function PHP_Serializer__Array(__s) {
	var ser = this.__common_array_object(__s);
	return ('a:'+ser[0]+':{'+ser[1]+'}');
}
function PHP_UnSerializer__Array() {
	var tmp = this.__common(new Array());
	++this.__c;
	return tmp;
}
function PHP_Serializer__serialize(what) {
	if(what==null)
		var ser = this.__undefined();
	else if(!this[what.constructor])
		var ser = this[Object](what);
	else
		var ser = this[what.constructor](what);
	return ser;
}
function PHP_UnSerializer__unserialize(what) {
	this.__c = 0;
	this.__s = what;
	delete what;
	return this[this.__s.substr(this.__c,1)]();
}
PHP_Serializer.prototype[Boolean] = PHP_Serializer__Boolean;
PHP_Serializer.prototype[Number] =
PHP_Serializer.prototype.__number = PHP_Serializer__Number;
PHP_Serializer.prototype[Function] = PHP_Serializer__Function;
PHP_Serializer.prototype[Date] = 
PHP_Serializer.prototype[Error] = 
PHP_Serializer.prototype[Object] = PHP_Serializer__Object;
PHP_Serializer.prototype[Array] = PHP_Serializer__Array;
PHP_Serializer.prototype.__common_array_object = PHP_Serializer__Common_ArrayObject;
PHP_Serializer.prototype.__undefined = PHP_Serializer__Undefined;
PHP_Serializer.prototype.serialize = PHP_Serializer__serialize;
PHP_Serializer.prototype.b = PHP_UnSerializer__Boolean;
PHP_Serializer.prototype.i =
PHP_Serializer.prototype.d = PHP_UnSerializer__Number;
PHP_Serializer.prototype.N = PHP_UnSerializer__Undefined;
PHP_Serializer.prototype.__common = PHP_UnSerializer__Common_ArrayObject;
PHP_Serializer.prototype.O = PHP_UnSerializer__Object;
PHP_Serializer.prototype.a = PHP_UnSerializer__Array;
PHP_Serializer.prototype.unserialize = PHP_UnSerializer__unserialize;


/**
 * Object EverGreen
 * 	a nice object for developers with some usefull methods.
 * -------------------------------------------------------------------
 * Methods List:
 * 	addFunctionEvent	=>	add multiple onload, onkeypress and other events
 *      getElement		=>	get an element by id in a crossbrowser way
 *      getXMLHTTP		=>	get an XMLHTTP object or false if is not possible
 *      in_array		=>	looking for a variable inside an array
 *      in_object		=>	looking for a variable inside an object
 *      is_mail			=>	check an email address
 *      is_uri			=>	check an uri
 *      ltrim			=>	as php function, trim left a string
 *      rtrim			=>	as php function, trim right a string
 *      sortArrayObjects	=>	order an array with nested arrays or objects by property name
 *      str_repeat		=>	as php function, repeat a string for many times
 *      trim			=>	as php function, trim a string
 *      var_dump		=> 	as php function, explode in a string a nested or simple var
 * ___________________________________________________________________
 *
 * @author	Andrea Giammarchi [www.devpro.it]
 * @version	0.0.1
 * @date	2006/02/27	16:10
 * @lastmod
 */
var EverGreen = {
	/** Sometimes we need more than one dedicated event.
	 * Example:
	 * 	EverGreen.addFunctionEvent(document, 'onkeydown', myFunc);
	 */
	addFunctionEvent: function(obj, evtName, evtNew) {
		var evtOld = obj[evtName];
		if(typeof(evtOld) !== 'function')
			obj[evtName] = evtNew;
		else {
			obj[evtName] = function(evt) {
				evtOld(evt);
				evtNew(evt);
			}
		}
	},

	/** Sometimes we need an element in a crossbrowser way
	 * Example:
	 * 	EverGreen.getElement('elementId').innerHTML = 'Hello World !';
	 */
	getElement: function(e) {
		return (!document.getElementById?document.all[e]:document.getElementById(e));
	},
	
	/** Sometimes we need a simple XMLHTTP bridge
	 * Example:
	 * 	var ajax = EverGreen.getXMLHTTP();
         *      if(ajax !== false) { .. ready for interacion }
         *      
	 * NOTE: in Internet Explorer 4 this method returns a "valid" object but not usable
	 */
	getXMLHTTP: function() {
		var s = ['undefined','MSIE 5','Microsoft','Msxml2','.XMLHTTP'];
		return ((typeof(XMLHttpRequest)!=s[0])?new XMLHttpRequest():
			((window.ActiveXObject)?new ActiveXObject(
				((navigator.userAgent.indexOf(s[1])!=-1)?s[2]:s[3])+s[4]):
			false));
	},
	
	/** Sometimes we need to know if an element is inside an array
	 * Example:
         *      aler(EverGreen.in_array('test', ['no', 'test', 'yes']));
         *      
         * NOTE: you can use recoursive true parameter for nested arrays
	 */
	in_array: function(elm, ar, recoursive) {
		var found = false;
		var a = ar.length;
		if(a > 0) {
			do {
				--a;
				if(elm === ar[a]) {
					found = true;
					a = 0;
				}
				else if(recoursive && typeof(ar[a]) === 'object')
					found = EverGreen.in_array(elm, ar[a], recoursive);
				if(found === true)
					a = 0;
			}while(a);
		};
		return found;
	},
	
	/** Sometimes we need to know if an element is inside an object
	 * Example:
         *      aler(EverGreen.in_object('test', {id:1, name:'test'}));
         *      
         * NOTE: you can use recoursive true parameter for nested objects
	 */
	in_object: function(elm, obj, recoursive) {
		var found = false;
		for(var a in obj) {
			if(elm === obj[a]) {
				found = true;
				break;
			}
			else if(recoursive && typeof(obj[a]) === 'object')
				found = EverGreen.in_object(elm, obj[a], recoursive);
			if(found === true)
				break;
		};
		return found;
	},

	/** Sometimes we need to know if an email is quite real
	 * Example:
         *      if(EverGreen.is_mail('test@test.uk')) { ... email ok }
	 */
	is_mail: function(m) {
		return Boolean(m.match(/^([a-z0-9]+[\._\-]?){1,3}([a-z0-9])*\@([a-z0-9]+[\.\-]?){1,3}([a-z0-9])*\.[a-z]{2,6}$/i));
	},

	/** Sometimes we need to know if an uri is quite real
	 * Example:
         *      if(EverGreen.is_uri('http://www.devpro.it')) { ... uri ok }
         *      
	 * NOTE: in Internet Explorer 4 this method returns a "valid" object but not usable
	 */
	is_uri: function(m) {
		return Boolean(m.match(/^(f|ht)tp(s)?:\/\/(www\.)?[^\"]+$/i));
	},
	
	/** Sometimes we need to trim left a string
	 * Example:
	 * 	var lefttrimmed = EverGreen.ltrim(' untrimmed '); // 'untrimmed '
         * -------------------------------------------
	 */
	ltrim: function(str) {
		return str.replace(/^\s*([^\000]+?)/,'$1');
	},
	
	/** Sometimes we need to trim right a string
	 * Example:
	 * 	var righttrimmed = EverGreen.rtrim(' untrimmed '); // ' untrimmed'
         * -------------------------------------------
	 */
	rtrim: function(str) {
		return str.replace(/^([^\000]+?)\s*$/,'$1');
	},

	/** Sometimes we need to order objects nested inside an array.
	 * Example:
	 * 	var nested = new Array();
	 *      nested.push({id:1, name:'Steve', age:27});
	 *      nested.push({id:2, name:'Arthur', age: 29});
	 *      nested.push({id:3, name:'Glenda', age:28});
	 *
	 *      // Example: order by age ASC
	 *      nested = EverGreen.sortArrayObjects(nested, 'name');
	 *      //	nested[0]	=>	{id:1, name:'Steve', age: 27}
	 *	//	nested[1]	=>	{id:3, name:'Glenda', age: 28}
	 *	//	nested[2]	=>	{id:2, name:'Arthur', age: 29}
	 *
	 *	// Example: order by id DESC (from last to first)
	 *      nested = EverGreen.sortArrayObjects(nested, 'id', 'DESC');
	 *      //	nested[0]	=>	{id:3, name:'Glenda', age: 28}
	 *	//	nested[1]	=>	{id:2, name:'Arthur', age: 29}
	 *	//	nested[2]	=>	{id:1, name:'Steve', age: 27}
	 */
	sortArrayObjects: function(ar, by, method) {
		if(method !== 'ASC' && method !== 'DESC')
			method = 'ASC';
		var how = method === 'ASC' ? ['>','<'] : ['<','>'];
		var tmpfunc = 'function sortBy(a,b) {\n' + 
		'	var r;\n' +
		'	if(a.' + by + how[0] + 'b.' + by + ')\n' +
		'		r = 1;\n' +
		'	else if(a.' + by + how[1] + 'b.' + by + ')\n' +
		'		r = -1;\n' +
		'	else\n' +
		'		r = 0;\n' +
		'	return r;\n' +
		'};';
		eval(tmpfunc);
		return ar.sort(sortBy);
	},

	/** Sometimes we need to repeat a char or a string
	 * Example:
	 * 	alert(EverGreen.str_repeat("hello", 2)); // hellohello
	 */
	str_repeat: function(what, times) {
		var r = '';
		if(times > 0) {
			var a = new Array(times);
			do {
				a[--times] = what;
			}while(times);
			r = a.join('');
		}
		return r;
	},
	
	/** Sometimes we need to trim a string
	 * Example:
	 * 	var trimmed = EverGreen.trim(' untrimmed '); // 'untrimmed'
         * -------------------------------------------
	 */
	trim: function(str) {
		return str.replace(/^\s*([^\000]+?)\s*$/,'$1');
	},

	/** Sometimes we need to dump some variable
	 * Example:
	 * 	alert(EverGreen.var_dump(EverGreen));
         * -------------------------------------------
         * NOTE:	don't use this methid with document objects, just with your variable
	 */
	var_dump: function(v) {
		function k2s(k) {
			return isNaN(k) ? '"' + k + '"' : k;
		};
		var p = arguments.length == 2 ? arguments[1] : 0;
		var r = '';
		if(v || v === false || v === 0) {
			switch(typeof(v)) {
				case 'string':
				case 'number':
				case 'boolean':
					r += '('+typeof(v)+') ' + v.toString();
					break;
				default:
					if(v instanceof Array)
						r += '[Array]\n';
					else
						r += '[Object]\n';
					for(var a in v)
						r += 	this.str_repeat('\t', p) +
							'[' + k2s(a) + '] => ' +
							this.var_dump(v[a], (p + 1)) +
							'\n';
					break;
			}
		}
		else
			r = 'null';
		return r;
	}
}

function checkMail(m) {
	// porting of php4 function
	// http://www.devpro.it/php4_id_2.html
	return Boolean(m.match(/^([a-z0-9]+[\._\-]?){1,3}([a-z0-9])*\@([a-z0-9]+[\.\-]?){1,3}([a-z0-9])*\.[a-z]{2,6}$/i));
}

/**
 * Object NetServices
 * 	This class allows users to connect to a dedicated php Gateway class and use
 * your PHP classes and methods directly from JavaScript.
 * This is the core of AJSHP project ( Asynchronous JavaScript Hypertext Prepocessor ).
 * _____________________________________________
 *
 * EXAMPLE:
 * 	// Service listener
 * 	var mainResponder = new Object();
 *	// Some class method listener progress [MethodName_Progress]
 * 	mainResponder.myMethod_Progress = function(v) {
 * 		document.write(v + '%');
 * 	}
 * 	// Some class method listener [MethodName_Result]
 * 	mainResponder.myMethod_Result = function(v) {
 * 		alert(v);
 * 	}
 * 	// called on error
 * 	mainResponder.onStatus = function(msg) {
 * 		alert(msg);
 * 	}
 * 	// called when service is valid and usable
 * 	mainResponder.onService = function(s) {
 * 		if(s)
 * 			serv.myMethod('PHP');
 * 		else
 * 			alert('Error, gateway is not working correctly.');
 * 	}
 * 	// setting default gateway php connector
 * 	NetServices.setDefaultGatewayUrl('gateway/Gateway.class.php');
 * 	// create a connection to gateway
 * 	var conn = NetServices.createGatewayConnection();
 * 	// and get service from class [ in this case Test.class.php ] with a listener
 * 	var serv = conn.getService('Test', mainResponder);
 * ---------------------------------------------
 * @dependencies	Client:	Object PHP_Serializer [ http://www.devpro.it/javascript_id_102.html ]
 * 				Object LoadVars [ http://www.devpro.it/javascript_id_92.html ]
 *			Server:	Class Gateway [ http://www.devpro.it/javascript_id_104.html ]
 * @author 		Andrea Giammarchi
 * @site		www.devpro.it
 * @date		2005/11/26
 * @lastmod		2005/12/09 11:30 [added listener MethodName_Progress callback]
 * @version		0.1b tested on FireFox 1.0.7, FireFox 1.5, IE 6 SP2 and Opera 8
 */
function NetServices() {
	
	/**
	 * Public method
	 * 	Sets gatewy variable to connect with php
	 *
	 *	this.setDefaultGatewayUrl(gateway:String):Void
	 *
	 * @param	String		valid and compatible Gateway.class.php
	 */
	this.setDefaultGatewayUrl = function(gateway) {
		__gateway = gateway;
	}
	
	/**
	 * Public method
	 * 	Returns a dedicated php gateway connector.
	 *
	 *	this.createGatewayConnection(Void):Object
         *
         * @return	Object		a new connection with a method to
         * 				call server side class method.
         *
         *		getService(className:String, listener:Object):Mixed
         *
         *		@param		String		the name of the class to use from JS
         *		@param		Object		listener with php class methods (with '_Result' suffix)
         *		@return		Mixed		variable returned from php called method
	 */
	this.createGatewayConnection = function() {
		function Connector(gateway) {
			this.getService = function(className, listener) {
				function __service(){};
				function __callListener(method) {
					if(typeof(listener[method]) == 'function') {
						var str = 'listener.' + method + '(';
						for(var a = 1; a < arguments.length; a++) {
							str += 'arguments[' + a + ']';
							if(a < (arguments.length - 1))
								str += ',';
						}
						str += ');';
						eval(str);
					}
				}
				function __addMethod(fname) {
					var fn = 'function ' + fname + '() {\n'
					+ '	var php = new PHP_Serializer();\n'
					+ '	var r = new LoadVars();\n'
					+ '	var s = new LoadVars();\n'
					+ '	var fname = "' + fname + '";\n'
					+ '	for(var a = 0; a < arguments.length; a++)\n'
					+ '		s["__pvt__" + a] = php.serialize(arguments[a]);\n'
					+ '	r.onLoad = function(s) {\n'
					+ '		if(s) {\n'
					+ '			var tmp = typeof(this.r) == "undefined" ? null : php.unserialize(this.r);\n'
					+ '			__callListener(fname + "_Result", tmp);\n'
					+ '		}\n'
					+ '		else\n'
					+ '			__callListener("onStatus", "Error for class " + className + " and its method " + fname);\n'
					+ '	}\n'
					+ '	r.onError = r.onData = function(s) {\n'
					+ '		delete onProgress;\n'
					+ '		this.onLoad(false);\n'
					+ '	}\n'
					+ '	function onProgress() {\n'
					+ '		var p = s.getProgress();\n'
					+ '		__callListener(fname + "_Progress", p);\n'
					+ '		if(p < 100)\n'
					+ '			setTimeout(onProgress, 10);\n'
					+ '	}\n'
					+ '	s.sendAndLoad(gateway + "?class=" + className + "&method=" + fname, r, "POST");\n'
					+ '	onProgress();\n'
					+ '}\n'
					+ 'var nf = ' + fname + ';';
					eval(fn);
					return nf;
				}
				var service = new __service();
				var __lv = new LoadVars();
				__lv.onLoad = function(s) {
					if(s) {
						var a = 0;
						while(typeof(this['r' + a]) != 'undefined') {
							service[this['r' + a]] = __addMethod(this['r' + a]);
							a++;
						}
						delete __addMethod;
					}
					__callListener('onService', s);
				}
				__lv.onError = __lv.onData = function(s) {
					this.onLoad(false);
				}
				__lv.load(gateway + '?class=' + className);
				return service;
			}
		}
		return new Connector(__gateway);
	}
	var __gateway = '';
}
var NetServices = new NetServices();

/**
 * Object Cookie
 * 	fast and simple way to manage one or more cookie from javascript.
 *
 * NOTE:
 * This object escape values then saved var will be always a string.
 * To storage complex variables or to preserve saved variable informations
 * you should combine this object with PHP_Serializer.
 * [ http://www.devpro.it/javascript_id_102.html ]
 * _____________________________________________
 *
 * QUICK EXAMPLE:
 *	Cookie.set('var', 'value');
 *	alert(Cookie.get('var'));
 *	Cookie.unset('var');
 *
 * EXAMPLE WITH PHP_Serializer OBJECT:
 *	var php = new PHP_Serializer();
 *	var complexVar = [true, 'test', 12345];
 *	Cookie.set('complexVar', php.serialize(complexVar));
 *	alert( typeof php.unserialize( Cookie.get('complexVar') ) );
 *	// will be object and not string then returned value is an array
 *	Cookie.unset('complexVar');
 * ---------------------------------------------
 * @author              Andrea Giammarchi
 * @site		www.devpro.it
 * @date                2005/12/19 11:00
 * @lastmod             2005/12/19 11:00
 * @credits		Special thanks to Dustin Diaz
 *			[ http://www.dustindiaz.com/top-ten-javascript/ ]
 * @version             1.0 tested FireFox 1.5, IE 6 SP2 and Opera 8
 */
var Cookie = {

	/**
	 * public method, returns value for chosed name or false if is not present
	 *	Cookie.get( cookiename:String ):String
	 * @param	String		name of saved cookie
	 * @return	String		value saved with chosed name
	 */
	get: function(name) {
		var dc = document.cookie;
		var cl = dc.indexOf(name+'=')+name.length;
		if(++cl > name.length) {
			var ce = dc.indexOf(';',cl);
			if(ce == -1)
				ce = dc.length;
			cl = unescape(dc.substr(cl,(ce-cl)));
		}
		else
			cl = false;
		return cl;
	},
	
	/**
	 * public method, sets a cookie
	 *	Cookie.set( name:String, value:Mixed[, exp:Int[, path:String[, domain:String[, secure:Boolean ]]]]):Void
	 * @param	String		name of cookie
	 * @param	Mixed		cookie value
	 * @param	Int		expiration date ( 0, 1, ... N days )
	 * @param	String		valid path for this cookie
	 * @param	String		domain for this cookie
	 * @param	Boolean		secure ( for example in https sites )
	 */
	set: function(name, value, exp, path, domain, secure) {
		var c = new Array();
		c.push(name + '=' + escape(value));
		var e = (exp > 0);
		if(e) {
			var n = new Date();
			exp = new Date(n.getTime()+(exp*86400000));
			c.push('expires='+exp.toGMTString());
		}
		if(path){c.push('path='+path);}
		if(domain){c.push('domain='+domain);}
		if(secure){c.push('secure');}
		document.cookie = c.join(';');
	},
	
	/**
	 * public method, removes a cookie if present.
	 *	Cookie.unset( name:String[, path:String[, domain:String]] ):Boolean
	 * @param	String		saved cookie name
	 * @param	String		path used for this cookie
	 * @param	String		domain used for this cookie
	 * @return	Boolean		true if was present and is removed or false
	 */
	unset: function(name, path, domain) {
		var result = this.get(name);
		if(result != false) {
			var c = new Array();
			c.push(name + '=');
			if(path){c.push('path=' + path);}
			if(domain){c.push('domain=' + domain);}
			c.push('expires=Thu, 01-Jan-1970 00:00:01 GMT');
			document.cookie = c.join(';');
		}
		return !!result;
	}
}